@@ -1,6 +1,6 @@
 import click
 
-from .cmds.clear import clear
+from .cmds.clean import clean
 from .cmds.infer import infer
 from .cmds.init import init
 from .cmds.push import push
@@ -19,4 +19,4 @@ cli.add_command(init)
 cli.add_command(push)
 cli.add_command(test)
 cli.add_command(infer)
-cli.add_command(clear)
+cli.add_command(clean)
